@@ -6,13 +6,17 @@ from pyconn import logger
 
 
 class Server:
-    def __init__(self):
+    def __init__(self, **kwargs):
         self.name = ""
         self.host = ""
         self.port = 0
         self.username = ""
         self.password = ""
+        self.timeout = 30.0  # seconds
         self.pandas = False
+        self.callback = None
+        self.encoding = "utf-8"
+        self.__dict__.update(kwargs)
 
     def to_string(self):
         return self.name
@@ -22,12 +26,8 @@ class KDB:
     def __init__(self, server):
         self.server_name = server.name
         self.q = qconnection.QConnection(host=server.host, port=server.port, username=server.username,
-                                         password=server.password,
-                                         pandas=server.pandas,
-                                         reader_class=AdvancedQReader)
-
-    def get_conn(self):
-        return self.q
+                                         password=server.password, encoding=server.encoding,
+                                         pandas=server.pandas, reader_class=AdvancedQReader)
 
     def close_conn(self):
         self.q.close()
